==> alfred_osint-0.2.3.tar.gz: alfred_osint-0.2.3/alfred_osint/lang/fr.py <==
# fr.py
# Français

encrypt1 = "Clé de chiffrement..."

title1 = "Merci beaucoup à nos partenaires !"

disclamer = "     Avertissement : Le fonctionnement de tous les sites et/ou proxys n'est pas garanti ! \n     En utilisant, vous prenez pleinement en compte vos actions"

targetusernames = "Les noms d'utilisateur cibles :"

version = "Version"

config1 = "Le fichier de configuration existe : "
config2 = "Le fichier de mise à jour existe : "
config3 = "Le dossier existe déjà : "
config4 = "Vérifier les mises à jour ? [Y/n] : ⤷ "
config5 = "Modifier la configuration ? [Y/n] : ⤷ "
config6 = "Que voulez-vous changer ? ⤷ "
config7 = "Création du dossier : "
config8 = "Le dossier existe déjà : "

configOption1 = "[1] Vérifier les mises à jour : "
configOption2 = "[2] Afficher les conseils : "
configOption3 = "[3] Chemin de téléchargement du site : "
configOption4 = "[4] Navigateur : "
configOption5 = "[5] Langue : "
configOptionA = "[A] Nettoyer Alfred. (Supprime les fichiers temporaires)"
configOptionB = "[B] Outils de développement."

configOption1Message = "Ok! [checkforupdates] est défini sur Oui. Changement en Non"
configOption2Message = "Ok! [showtips] est défini sur Oui. Changement en Non"
configOption3Message = "Nouveau chemin : ⤷ "
configOption4Message = """
             Types pris en charge :
                         Firefox
                         Edge
                         Chrome
                         """
configOption5Message = """
            Veuillez saisir votre code de langue
            Langues prises en charge :
                it = italien
                fr = français
                il = hébreu 
                en = anglais 
                ar = arabe 
                es = espagnol
                         """
configOptionAMessage = "Fait!"
configOptionBMessage = "Bienvenue dans le menu développeur!"

configOption1Message2 = "Ok! [checkforupdates] est défini sur Non. Changement en Oui"
configOption2Message2 = "Ok! [showtips] est défini sur Non. Changement en Oui"
configOptionBMessage2 = (
    "NE DONNEZ PAS LES CLÉS SUIVANTES À QUICONQUE SAUF À UN DÉVELOPPEUR D'ALFRED."
)
configOptionBMessage3 = "privatekey: "
configOptionBMessage4 = "syscrypt: "

target = "Cible : ⤷ "
browser = "Navigateur : "

file_not_found = "Fichier introuvable : {filename}"
permission_denied = "Autorisation refusée pour {operation} sur {path}"

note = "Remarque ! "
path = "CHEMIN : ⤷ "
warning1 = "Les sites peuvent ne pas autoriser le téléchargement de leurs fichiers de site. Utilisez-les à vos risques et périls."
warning2 = "L'utilisation du Webscraper est assez lente."
warning3 = "Ceci est votre premier lancement :D Vous devrez peut-être redémarrer Alfred pour utiliser tous les modules"
warning4 = "Vous utilisez une préversion d'Alfred !"

confirm1 = "Voulez-vous télécharger des images/vidéos ? [Y/n] : ⤷ "
confirm2 = "Exécuter à nouveau ? : [Y/n] : ⤷ "

prompt1 = "Entrez à nouveau le site : ⤷ "
prompt2 = (
    "Veuillez signaler tous les bogues ou erreurs à notre dépôt ou serveur Discord."
)
prompt3 = "Vous pouvez désactiver la mise à jour dans le fichier de configuration"
prompt4 = "Rejoignez notre Discord : https://discord.gg/xrdjxyuSQt"
prompt5 = "Ok! Je demanderai plus tard...."
prompt6 = " Sites non fonctionnels..."

download1 = "Téléchargement "
updates = "Les mises à jour sont activées !"

idk1 = "Pas sûr de ce que tu veux dire...."
idk2 = "Pas sûr de ce que tu veux dire. Je demanderai plus tard"
idk3 = "Pas sûr.... Mais vous pouvez vérifier ici : "
scan1 = "recherche de sites avec : "

status1 = "En cours...."
status2 = "Création/remplacement du fichier de sauvegarde."
status3 = "Réinstallation............"
status4 = "Retour à Alfred bientôt..."
status5 = "Test en cours..."
status6 = "Arrêt..... Enregistré dans captured/working.txt"
status7 = "En arrêt........"

save1 = "Résultats sauvegardés dans"
save2 = "Résultats sauvegardés dans le fichier"

error1 = "Erreur d'autorisation"
error2 = "Erreur de type"
error3 = "Impossible de trouver le fichier de sauvegarde !"
error4 = "Le répertoire n'existe pas."
error5 = "Impossible de trouver les fichiers nécessaires. Tentative de réinstallation d'Alfred"
error6 = "Oh, oh, erreur ! Il semble que la connexion ne fonctionne pas. Vérifiez votre connexion ou votre proxy, puis réessayez :"
error7 = "Impossible de trouver le fichier du site"
error8 = "Erreur de téléchargement du contenu Web !"
error9 = "Erreur avec le fichier du site"
error10 = "Sélection de webdriver invalide."
error11 = "Une erreur s'est produite : "

fileshare1 = "[*] Écoute en tant que"
fileshare2 = "est connecté."
fileshare3 = "Réception"

wikiOption1 = "[1] Installation"
wikiOption2 = "[2] Options"
wikiOption3 = "[3] Erreurs"
wikiOption4 = "[4] Alfred sombre"
wikiOption5 = "[5] Modules"

wikilist = "Vous pouvez trouver des informations à ce sujet ici : "

rqUname = "Nom d'utilisateur demandé : "

sender1 = "[+] Connexion à"
sender2 = "[+] Connecté."
sender3 = "Envoi."
sender4 = "Fichier à envoyer : ⤷ "

fs1 = "Serveur hôte ? [Y/N]: ⤷ "
fs2 = "En attente de connexion à l'hôte !"
fs3 = "En attente de connexion du client !"

siteDl1 = "Nombre total de fichiers de script sur la page :"
siteDl2 = "Nombre total de fichiers CSS sur la page :"

==> alfred_osint-0.2.3.4.tar.gz: alfred_osint-0.2.3.4/alfred_osint/lang/fr.py <==
# fr.py
# Français

encrypt1 = "Clé de chiffrement..."

title1 = "Merci beaucoup à nos partenaires !"

disclamer = "     Avertissement : Le fonctionnement de tous les sites et/ou proxys n'est pas garanti ! \n     En utilisant, vous prenez pleinement en compte vos actions"

targetusernames = "Les noms d'utilisateur cibles :"

version = "Version"

config1 = "Le fichier de configuration existe "
config2 = "Le fichier de mise à jour existe "
config3 = "Le dossier existe déjà : "
config4 = "Vérifier les mises à jour ? [Y/n] : ⤷ "
config5 = "Modifier la configuration ? [Y/n] : ⤷ "
config6 = "Que voulez-vous changer ? ⤷ "
config7 = "Création du dossier : "
config8 = "Le dossier existe déjà : "

configOption1 = "[1] Vérifier les mises à jour : "
configOption2 = "[2] Afficher les conseils : "
configOption3 = "[3] Chemin de téléchargement du site : "
configOption4 = "[4] Navigateur : "
configOption5 = "[5] Langue : "
configOptionA = "[A] Nettoyer Alfred. (Supprime les fichiers temporaires)"
configOptionB = "[B] Outils de développement."

configOption1Message = "Ok! [checkforupdates] est défini sur Oui. Changement en Non"
configOption2Message = "Ok! [showtips] est défini sur Oui. Changement en Non"
configOption3Message = "Nouveau chemin : ⤷ "
configOption4Message = """
             Types pris en charge :
                         Firefox
                         Edge
                         Chrome
                         """
configOption5Message = """
            Veuillez saisir votre code de langue
            Langues prises en charge :
                it = Italien
                en = Anglais
                il = Hébreu
                es = Espagnol
                fr = Français
                ar = Arabe
                de = Allemand
                ru = Russe
                hi = Hindi
                         """
configOptionAMessage = "Fait!"
configOptionBMessage = "Bienvenue dans le menu développeur!"

configOption1Message2 = "Ok! [checkforupdates] est défini sur Non. Changement en Oui"
configOption2Message2 = "Ok! [showtips] est défini sur Non. Changement en Oui"
configOptionBMessage2 = (
    "NE DONNEZ PAS LES CLÉS SUIVANTES À QUICONQUE SAUF À UN DÉVELOPPEUR D'ALFRED."
)
configOptionBMessage3 = "privatekey: "
configOptionBMessage4 = "syscrypt: "

target = "Cible : ⤷ "
browser = "Navigateur : "

file_not_found = "Fichier introuvable : {filename}"
permission_denied = "Autorisation refusée pour {operation} sur {path}"

note = "Remarque ! "
path = "CHEMIN : ⤷ "
warning1 = "Les sites peuvent ne pas autoriser le téléchargement de leurs fichiers de site. Utilisez-les à vos risques et périls."
warning2 = "L'utilisation du Webscraper est assez lente."
warning3 = "Ceci est votre premier lancement :D Vous devrez peut-être redémarrer Alfred pour utiliser tous les modules"
warning4 = "Vous utilisez une préversion d'Alfred !"

confirm1 = "Voulez-vous télécharger des images/vidéos ? [Y/n] : ⤷ "
confirm2 = "Exécuter à nouveau ? : [Y/n] : ⤷ "

prompt1 = "Entrez à nouveau le site : ⤷ "
prompt2 = (
    "Veuillez signaler tous les bogues ou erreurs à notre dépôt ou serveur Discord."
)
prompt3 = "Vous pouvez désactiver la mise à jour dans le fichier de configuration"
prompt4 = "Rejoignez notre Discord : https://discord.gg/xrdjxyuSQt"
prompt5 = "Ok! Je demanderai plus tard...."
prompt6 = " Sites non fonctionnels..."

download1 = "Téléchargement "
updates = "Les mises à jour sont activées !"

idk1 = "Pas sûr de ce que tu veux dire...."
idk2 = "Pas sûr de ce que tu veux dire. Je demanderai plus tard"
idk3 = "Pas sûr.... Mais vous pouvez vérifier ici : "
scan1 = "recherche de sites avec : "

status1 = "En cours...."
status2 = "Création/remplacement du fichier de sauvegarde."
status3 = "Réinstallation............"
status4 = "Retour à Alfred bientôt..."
status5 = "Test en cours..."
status6 = "Arrêt..... Enregistré dans captured/working.txt"
status7 = "En arrêt........"

save1 = "Résultats sauvegardés dans"
save2 = "Résultats sauvegardés dans le fichier"

error1 = "Erreur d'autorisation"
error2 = "Erreur de type"
error3 = "Impossible de trouver le fichier de sauvegarde !"
error4 = "Le répertoire n'existe pas."
error5 = "Impossible de trouver les fichiers nécessaires. Tentative de réinstallation d'Alfred"
error6 = "Oh, oh, erreur ! Il semble que la connexion ne fonctionne pas. Vérifiez votre connexion ou votre proxy, puis réessayez :"
error7 = "Impossible de trouver le fichier du site"
error8 = "Erreur de téléchargement du contenu Web !"
error9 = "Erreur avec le fichier du site"
error10 = "Sélection de webdriver invalide."
error11 = "Une erreur s'est produite : "

fileshare1 = "[*] Écoute en tant que"
fileshare2 = "est connecté."
fileshare3 = "Réception"

wikiOption1 = "[1] Installation"
wikiOption2 = "[2] Options"
wikiOption3 = "[3] Erreurs"
wikiOption4 = "[4] Alfred sombre"
wikiOption5 = "[5] Modules"

wikilist = "Vous pouvez trouver des informations à ce sujet ici : "

rqUname = "Nom d'utilisateur demandé : "

sender1 = "[+] Connexion à"
sender2 = "[+] Connecté."
sender3 = "Envoi."
sender4 = "Fichier à envoyer : ⤷ "

fs1 = "Serveur hôte ? [Y/N]: ⤷ "
fs2 = "En attente de connexion à l'hôte !"
fs3 = "En attente de connexion du client !"

siteDl1 = "Nombre total de fichiers de script sur la page :"
siteDl2 = "Nombre total de fichiers CSS sur la page :"
